==> jc-1.4.0.tar.gz: gnu/xml/util/DoParse__24MyErrorHandler.h <==
// class gnu.xml.util.DoParse$MyErrorHandler

// class file dependencies
// @dep_class 5f927cefa222123b gnu_xml_util_DoParse__24MyErrorHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_util_DoParse__24MyErrorHandler_H_
#define _JC_gnu_xml_util_DoParse__24MyErrorHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_xml_sax_SAXParseException$object;

// Typedefs
typedef struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_refs	_jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_refs;
typedef struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_nonrefs	_jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_nonrefs;
typedef struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$refs	_jc_gnu_xml_util_DoParse__24MyErrorHandler$refs;
typedef struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$nonrefs	_jc_gnu_xml_util_DoParse__24MyErrorHandler$nonrefs;
typedef struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object	_jc_gnu_xml_util_DoParse__24MyErrorHandler$object;

typedef const struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vmethods	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vmethods;
typedef const struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vtable	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vtable;
typedef const struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vtype	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vtype;

// Constructors
extern void _jc_gnu_xml_util_DoParse__24MyErrorHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *);

// Virtual methods
extern void _jc_gnu_xml_util_DoParse__24MyErrorHandler$method$error$7d923204368685db(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);
extern void _jc_gnu_xml_util_DoParse__24MyErrorHandler$method$fatalError$52809331a66c9498(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);
extern void _jc_gnu_xml_util_DoParse__24MyErrorHandler$method$warning$72c08df791ab6f01(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_util_DoParse__24MyErrorHandler$method_info$error$7d923204368685db;
extern _jc_method _jc_gnu_xml_util_DoParse__24MyErrorHandler$method_info$fatalError$52809331a66c9498;
extern _jc_method _jc_gnu_xml_util_DoParse__24MyErrorHandler$method_info$warning$72c08df791ab6f01;

// Virtual methods structure
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vmethods {
	void	(*error$7d923204368685db)(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);
	void	(*fatalError$52809331a66c9498)(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);
	void	(*warning$72c08df791ab6f01)(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *);
};

// Vtable
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vmethods	gnu_xml_util_DoParse__24MyErrorHandler;
};

// Vtype
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$refs {
    _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_refs	gnu_xml_util_DoParse__24MyErrorHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_nonrefs	gnu_xml_util_DoParse__24MyErrorHandler;
};

// Object instance structure
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object {
	_jc_gnu_xml_util_DoParse__24MyErrorHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vtype	*vtype;
	_jc_gnu_xml_util_DoParse__24MyErrorHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_DoParse__24MyErrorHandler$vtype _jc_gnu_xml_util_DoParse__24MyErrorHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_DoParse__24MyErrorHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_DoParse__24MyErrorHandler$class_object;

#endif	/* _JC_gnu_xml_util_DoParse__24MyErrorHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/util/DoParse__24MyErrorHandler.h <==
// class gnu.xml.util.DoParse$MyErrorHandler

// class file dependencies
// @dep_class 5f927cefa222123b gnu_xml_util_DoParse__24MyErrorHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_util_DoParse__24MyErrorHandler_H_
#define _JC_gnu_xml_util_DoParse__24MyErrorHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_xml_sax_SAXParseException$object;

// Typedefs
typedef struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_refs	_jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_refs;
typedef struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_nonrefs	_jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_nonrefs;
typedef struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$refs	_jc_gnu_xml_util_DoParse__24MyErrorHandler$refs;
typedef struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$nonrefs	_jc_gnu_xml_util_DoParse__24MyErrorHandler$nonrefs;
typedef struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object	_jc_gnu_xml_util_DoParse__24MyErrorHandler$object;

typedef const struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vmethods	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vmethods;
typedef const struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vtable	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vtable;
typedef const struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vtype	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vtype;

// Constructors
extern void _jc_gnu_xml_util_DoParse__24MyErrorHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_util_DoParse__24MyErrorHandler$method$error$7d923204368685db(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_DoParse__24MyErrorHandler$method$fatalError$52809331a66c9498(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_DoParse__24MyErrorHandler$method$warning$72c08df791ab6f01(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_util_DoParse__24MyErrorHandler$method_info$error$7d923204368685db;
extern _jc_method _jc_gnu_xml_util_DoParse__24MyErrorHandler$method_info$fatalError$52809331a66c9498;
extern _jc_method _jc_gnu_xml_util_DoParse__24MyErrorHandler$method_info$warning$72c08df791ab6f01;

// Virtual methods structure
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vmethods {
	void	(*error$7d923204368685db)(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
	void	(*fatalError$52809331a66c9498)(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
	void	(*warning$72c08df791ab6f01)(_jc_env *, struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vmethods	gnu_xml_util_DoParse__24MyErrorHandler;
};

// Vtype
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$refs {
    _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_refs	gnu_xml_util_DoParse__24MyErrorHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_DoParse__24MyErrorHandler$sub_nonrefs	gnu_xml_util_DoParse__24MyErrorHandler;
};

// Object instance structure
struct _jc_gnu_xml_util_DoParse__24MyErrorHandler$object {
	_jc_gnu_xml_util_DoParse__24MyErrorHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_DoParse__24MyErrorHandler$vtype	*vtype;
	_jc_gnu_xml_util_DoParse__24MyErrorHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_DoParse__24MyErrorHandler$vtype _jc_gnu_xml_util_DoParse__24MyErrorHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_DoParse__24MyErrorHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_DoParse__24MyErrorHandler$class_object;

#endif	/* _JC_gnu_xml_util_DoParse__24MyErrorHandler_H_ */
